$OpenBSD$
--- src/unix/linux_snd.c.orig	Tue Aug 10 18:17:01 2010
+++ src/unix/linux_snd.c	Sun Aug 15 02:08:36 2010
@@ -34,8 +34,8 @@ If you have questions concerning this license or the a
 #include <sys/mman.h>
 #include <sys/shm.h>
 #include <sys/wait.h>
-#ifdef __linux__ // rb0101023 - guard this
-#include <linux/soundcard.h>
+#ifdef __OpenBSD__ // rb0101023 - guard this
+#include <soundcard.h>
 #endif
 #ifdef __FreeBSD__ // rb0101023 - added
 #include <sys/soundcard.h>
@@ -93,10 +93,10 @@ qboolean SNDDMA_Init( void ) {
 		sndbits = Cvar_Get( "sndbits", "16", CVAR_ARCHIVE );
 		sndspeed = Cvar_Get( "sndspeed", "0", CVAR_ARCHIVE );
 		sndchannels = Cvar_Get( "sndchannels", "2", CVAR_ARCHIVE );
-		snddevice = Cvar_Get( "snddevice", "/dev/dsp", CVAR_ARCHIVE );
+		snddevice = Cvar_Get( "snddevice", "/dev/audio", CVAR_ARCHIVE );
 	}
 
 	// open /dev/dsp, confirm capability to mmap, and get size of dma buffer
 	if ( !audio_fd ) {
 		seteuid( saved_euid );
 
@@ -93,10 +93,10 @@ qboolean SNDDMA_Init( void ) {
 	}
 
-	// open /dev/dsp, confirm capability to mmap, and get size of dma buffer
+	// open /dev/audio, confirm capability to mmap, and get size of dma buffer
 	if ( !audio_fd ) {
 		seteuid( saved_euid );
